@@ -3,10 +3,11 @@ Functionality for formatting vulnerability results as a set of human-readable co
 """
 
 from itertools import zip_longest
-from typing import Any, Dict, Iterable, List, Tuple, cast
+from typing import Any, Dict, Iterable, List, Optional, Tuple, cast
 
 from packaging.version import Version
 
+import pip_audit._fix as fix
 import pip_audit._service as service
 
 from .interface import VulnerabilityFormat
@@ -39,7 +40,18 @@ class ColumnsFormat(VulnerabilityFormat):
         """
         self.output_desc = output_desc
 
-    def format(self, result: Dict[service.Dependency, List[service.VulnerabilityResult]]) -> str:
+    @property
+    def is_manifest(self):
+        """
+        See `VulnerabilityFormat.is_manifest`.
+        """
+        return False
+
+    def format(
+        self,
+        result: Dict[service.Dependency, List[service.VulnerabilityResult]],
+        fixes: List[fix.FixVersion],
+    ) -> str:
         """
         Returns a column formatted string for a given mapping of dependencies to vulnerability
         results.
@@ -48,6 +60,8 @@ class ColumnsFormat(VulnerabilityFormat):
         """
         vuln_data: List[List[Any]] = []
         header = ["Name", "Version", "ID", "Fix Versions"]
+        if fixes:
+            header.append("Applied Fix")
         if self.output_desc:
             header.append("Description")
         vuln_data.append(header)
@@ -55,20 +69,24 @@ class ColumnsFormat(VulnerabilityFormat):
             if dep.is_skipped():
                 continue
             dep = cast(service.ResolvedDependency, dep)
+            applied_fix = next((f for f in fixes if f.dep == dep), None)
             for vuln in vulns:
-                vuln_data.append(self._format_vuln(dep, vuln))
-
-        vuln_strings, sizes = tabulate(vuln_data)
-
-        # Create and add a separator.
-        if len(vuln_data) > 0:
-            vuln_strings.insert(1, " ".join(map(lambda x: "-" * x, sizes)))
+                vuln_data.append(self._format_vuln(dep, vuln, applied_fix))
 
         columns_string = str()
-        for row in vuln_strings:
-            if columns_string:
-                columns_string += "\n"
-            columns_string += row
+
+        # If it's just a header, don't bother adding it to the output
+        if len(vuln_data) > 1:
+            vuln_strings, sizes = tabulate(vuln_data)
+
+            # Create and add a separator.
+            if len(vuln_data) > 0:
+                vuln_strings.insert(1, " ".join(map(lambda x: "-" * x, sizes)))
+
+            for row in vuln_strings:
+                if columns_string:
+                    columns_string += "\n"
+                columns_string += row
 
         # Now display the skipped dependencies
         skip_data: List[List[Any]] = []
@@ -91,12 +109,17 @@ class ColumnsFormat(VulnerabilityFormat):
         skip_strings.insert(1, " ".join(map(lambda x: "-" * x, sizes)))
 
         for row in skip_strings:
-            columns_string += "\n" + row
+            if columns_string:
+                columns_string += "\n"
+            columns_string += row
 
         return columns_string
 
     def _format_vuln(
-        self, dep: service.ResolvedDependency, vuln: service.VulnerabilityResult
+        self,
+        dep: service.ResolvedDependency,
+        vuln: service.VulnerabilityResult,
+        applied_fix: Optional[fix.FixVersion],
     ) -> List[Any]:
         vuln_data = [
             dep.canonical_name,
@@ -104,6 +127,8 @@ class ColumnsFormat(VulnerabilityFormat):
             vuln.id,
             self._format_fix_versions(vuln.fix_versions),
         ]
+        if applied_fix is not None:
+            vuln_data.append(self._format_applied_fix(applied_fix))
         if self.output_desc:
             vuln_data.append(vuln.description)
         return vuln_data
@@ -116,3 +141,16 @@ class ColumnsFormat(VulnerabilityFormat):
             dep.canonical_name,
             dep.skip_reason,
         ]
+
+    def _format_applied_fix(self, applied_fix: fix.FixVersion) -> str:
+        if applied_fix.is_skipped():
+            applied_fix = cast(fix.SkippedFixVersion, applied_fix)
+            return (
+                f"Failed to fix {applied_fix.dep.canonical_name} ({applied_fix.dep.version}): "
+                f"{applied_fix.skip_reason}"
+            )
+        applied_fix = cast(fix.ResolvedFixVersion, applied_fix)
+        return (
+            f"Successfully upgraded {applied_fix.dep.canonical_name} ({applied_fix.dep.version} "
+            f"=> {applied_fix.version})"
+        )
